| Title: | Fast Simultaneous Confidence Bands Based on the Efficient Influence Function and Multiplier Bootstrap |
|---|---|
| Description: | Compute critical values for constructing uniform (simultaneous) confidence bands. The critical value is calculated using a multiplier bootstrap of the empirical efficient influence function as described by Kennedy (2019) <doi:10.1080/01621459.2017.1422737>. The multiplier bootstrap does not require resampling of the data but only simulation of the multipliers and is thus computationally efficient. |
| Authors: | Nicholas Williams [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-1378-4831>) |
| Maintainer: | Nicholas Williams <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.2 |
| Built: | 2026-06-03 08:59:26 UTC |
| Source: | https://github.com/nt-williams/simul |
A list of 5 simulated influence functions.
eifeif
An object of class list of length 5.
Find Simultaneous Confidence Band Critical Value
simul(x, eif, nobs, reps = 1e+05, level = 0.95)simul(x, eif, nobs, reps = 1e+05, level = 0.95)
x |
A list of parameter estimates. |
eif |
A list of empirical efficient influence functions corresponding to the estimates in |
nobs |
The number of observations. |
reps |
The number of repetitions to use for the multiplier bootstrap, the default is 1e5. |
level |
The confidence level for the critical value should be calculated for, the default is 0.95. |
The estimated critical value satisfying the requirements for a uniform confidence band around all estimates.
data(eif) psi <- lapply(eif, function(x) mean(x)) n <- length(eif[[1]]) simul(psi, eif, n)data(eif) psi <- lapply(eif, function(x) mean(x)) n <- length(eif[[1]]) simul(psi, eif, n)